@@ -4,13 +4,14 @@ using the parsing library lark: https://lark-parser.readthedocs.io/en/latest/
 The goal is to separate the requirement indicator (i.e. Muss, Soll, Kann, X, O, U) from the condition expression
 and also several modal marks expressions if there are more than one.
 """
-from typing import Dict
+from functools import lru_cache
 
 from lark import Lark, Token, Tree
 from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
 
 # pylint: disable=anomalous-backslash-in-string
 from ahbicht.expressions import parsing_logger
+from ahbicht.utility_functions import tree_copy
 
 GRAMMAR = """
 ahb_expression: modal_mark_expression+
@@ -29,12 +30,10 @@ CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\sP\.UB]+/i
 # and CTRL+F for "Mus[2]" in the unittest that fails if you remove the lookahead.
 _parser = Lark(GRAMMAR, start="ahb_expression")
 
-_cache: Dict[str, Tree[Token]] = {}  #: holds the ahb expression as key and the parsed Tree as value
 
-
-def parse_ahb_expression_to_single_requirement_indicator_expressions(
-    ahb_expression: str, disable_cache: bool = False
-) -> Tree[Token]:
+@tree_copy
+@lru_cache(maxsize=65536)
+def parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_expression: str) -> Tree[Token]:
     """
     Parse a given expression as it appears in the AHB with the help of the here defined grammar to a lark tree.
     The goal is to separate the requirement indicator (i.e. Muss/M Soll/S Kann/K, X, O, U) from the condition expression
@@ -42,14 +41,10 @@ def parse_ahb_expression_to_single_requirement_indicator_expressions(
     Whitespaces are ignored.
 
     :param ahb_expression: e.g. 'Muss[45]U[52] Soll[1]'
-    :param disable_cache: set to true to disable caching
     :return parsed_tree:
     """
-    if (not disable_cache) and ahb_expression in _cache:
-        return _cache[ahb_expression]
     try:
         parsed_tree = _parser.parse(ahb_expression)
-        _cache.update({ahb_expression: parsed_tree})
         parsing_logger.debug("Successfully parsed '%s' as AHB expression", ahb_expression)
     except (UnexpectedEOF, UnexpectedCharacters, TypeError) as eof:
         raise SyntaxError(
