@@ -5,7 +5,8 @@ the parsing library lark: https://lark-parser.readthedocs.io/en/latest/
 The used terms are defined in the README_conditions.md.
 """
 # pylint:disable=cyclic-import
-from typing import Dict, List, Union
+from functools import lru_cache
+from typing import List, Union
 
 from lark import Lark, Token, Tree
 from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
@@ -13,6 +14,7 @@ from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
 from ahbicht.condition_node_distinction import ConditionNodeType, derive_condition_node_type
 from ahbicht.content_evaluation.categorized_key_extract import CategorizedKeyExtract
 from ahbicht.expressions import parsing_logger
+from ahbicht.utility_functions import tree_copy
 
 GRAMMAR = r"""
 ?expression: expression "O"i expression -> or_composition
@@ -40,10 +42,10 @@ PACKAGE_KEY: INT "P" // a TERMINAL for all INTs followed by "P" (high priority)
 """
 _parser = Lark(GRAMMAR, start="expression")
 
-_cache: Dict[str, Tree[Token]] = {}  #: holds the condition expression as key and the parsed Tree as value
 
-
-def parse_condition_expression_to_tree(condition_expression: str, disable_cache: bool = True) -> Tree[Token]:
+@tree_copy
+@lru_cache(maxsize=65536)
+def parse_condition_expression_to_tree(condition_expression: str) -> Tree[Token]:
     """
     Parse a given condition expression with the help of the here defined grammar to a lark tree.
     The grammar starts with condition keys, e.g. [45] and combines them with
@@ -52,14 +54,10 @@ def parse_condition_expression_to_tree(condition_expression: str, disable_cache:
     Whitespaces are ignored.
 
     :param condition_expression: str, e.g. '[45]U[502]O[1][906]'
-    :param disable_cache: set to False to enable caching
     :return parsed_tree: Tree
     """
-    if (not disable_cache) and condition_expression in _cache:
-        return _cache[condition_expression]
     try:
         parsed_tree = _parser.parse(condition_expression)
-        _cache.update({condition_expression: parsed_tree})
         parsing_logger.debug("Successfully parsed '%s' as condition expression", condition_expression)
     except (UnexpectedEOF, UnexpectedCharacters, TypeError) as eof:
         raise SyntaxError(
